NutritionRecordExtensions extension
Extension methods for NutritionRecord.
Methods
-
withIngredient(
NutritionRecordIngredient ingredient) → NutritionRecord -
Available on NutritionRecord, provided by the NutritionRecordExtensions extension
Creates a new nutrition record with an ingredient added. -
withoutIngredient(
NutritionRecordIngredient ingredient) → NutritionRecord -
Available on NutritionRecord, provided by the NutritionRecordExtensions extension
Creates a new nutrition record with an ingredient removed. -
withServingSize(
double servingSize, NutritionalUnit unit) → NutritionRecord -
Available on NutritionRecord, provided by the NutritionRecordExtensions extension
Creates a new nutrition record with updated serving size and unit.