Unit enum
Values
- bpm → const Unit
- meters → const Unit
- miles → const Unit
- kcal → const Unit
- count → const Unit
- mPerSec → const Unit
- celsius → const Unit
- fahrenheit → const Unit
- percentage → const Unit
- ms → const Unit
- seconds → const Unit
- degrees → const Unit
- sleepStage → const Unit
- secPerM → const Unit
- rpm → const Unit
- spm → const Unit
- breathsPerMin → const Unit
- g → const Unit
- lbs → const Unit
- st → const Unit
- mmHg → const Unit
- mLPerKgPerMin → const Unit
- uV → const Unit
- mgPerDl → const Unit
- w → const Unit
- unknown → const Unit
-
Unknown value was sent from API. SDK should be updated to use the newest API responses.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → Unit